@@ -33,12 +33,16 @@
 #endif
 
 #include <stdio.h>
+#include <stdlib.h>
+
+char *copyrightstring (AFfilehandle file);
 
 void printfileinfo (char *filename)
 {
 	int				version;
 	AFfilehandle	file;
 	int				sampleFormat, sampleWidth, byteOrder;
+	char			*copyright;
 
 	file = afOpenFile(filename, "r", NULL);
 
@@ -84,19 +88,61 @@ void printfileinfo (char *filename)
 			break;
 	}
 
-	printf("Audio Data     %d bytes begins at offset %d (%x hex)\n",
+	printf("Audio Data     %ld bytes begins at offset %ld (%lx hex)\n",
 		afGetTrackBytes(file, AF_DEFAULT_TRACK),
 		afGetDataOffset(file, AF_DEFAULT_TRACK),
 		afGetDataOffset(file, AF_DEFAULT_TRACK));
-	printf("               %d channels, %d frames\n",
+	printf("               %d channel%s, %ld frames\n",
 		afGetChannels(file, AF_DEFAULT_TRACK),
+		afGetChannels(file, AF_DEFAULT_TRACK) > 1 ? "s" : "",
 		afGetFrameCount(file, AF_DEFAULT_TRACK));
 
-	printf("Sampling Rate  %.lf Hz\n", afGetRate(file, AF_DEFAULT_TRACK));
+	printf("Sampling Rate  %.2f Hz\n", afGetRate(file, AF_DEFAULT_TRACK));
 
-	printf("Duration       %.2lf seconds\n",
+	printf("Duration       %.2f seconds\n",
 		afGetFrameCount(file, AF_DEFAULT_TRACK) /
 		afGetRate(file, AF_DEFAULT_TRACK));
 
+	copyright = copyrightstring(file);
+	if (copyright)
+	{
+		printf("Copyright      %s\n", copyright);
+		free(copyright);
+	}
+
 	afCloseFile(file);
 }
+
+char *copyrightstring (AFfilehandle file)
+{
+	char	*copyright = NULL;
+	int		*miscids;
+	int		i, misccount;
+
+	misccount = afGetMiscIDs(file, NULL);
+	miscids = malloc(sizeof (int) * misccount);
+	afGetMiscIDs(file, miscids);
+
+	for (i=0; i<misccount; i++)
+	{
+		char	*data;
+		int		datasize;
+
+		if (afGetMiscType(file, miscids[i]) != AF_MISC_COPY)
+			continue;
+
+		/*
+			If this code executes, the miscellaneous chunk is a
+			copyright chunk.
+		*/
+		datasize = afGetMiscSize(file, miscids[i]);
+		data = malloc(datasize);
+		afReadMisc(file, miscids[i], data, datasize);
+		copyright = data;
+		break;
+	}
+
+	free(miscids);
+
+	return copyright;
+}
